## $Id: browser.py 15809 2019-11-15 07:28:55Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.kofa.applicants.browser import (
    ApplicantRegistrationPage, ApplicantsContainerPage)
from waeup.kofa.applicants.interfaces import (
    ISpecialApplicant, IApplicantsContainer)
from kofacustom.nigeria.applicants.browser import (
    NigeriaApplicantDisplayFormPage,
    NigeriaApplicantManageFormPage,
    NigeriaApplicantEditFormPage,
    NigeriaPDFApplicationSlip)
from waeup.kofa.widgets.datewidget import (
    FriendlyDateDisplayWidget,
    FriendlyDatetimeDisplayWidget)
from kofacustom.nigeria.applicants.interfaces import (
    UG_OMIT_DISPLAY_FIELDS,
    UG_OMIT_PDF_FIELDS,
    UG_OMIT_MANAGE_FIELDS,
    UG_OMIT_EDIT_FIELDS,
    PG_OMIT_DISPLAY_FIELDS,
    PG_OMIT_PDF_FIELDS,
    PG_OMIT_MANAGE_FIELDS,
    PG_OMIT_EDIT_FIELDS,
    )
from kofacustom.iuokada.applicants.interfaces import (
    ICustomPGApplicant, ICustomUGApplicant,
    ICustomPGApplicantEdit, ICustomUGApplicantEdit,
    ICustomApplicantOnlinePayment
    )
from kofacustom.iuokada.interfaces import MessageFactory as _

class CustomApplicantsContainerPage(ApplicantsContainerPage):
    """The standard view for regular applicant containers.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(IApplicantsContainer).omit(
            'title', 'description')
        form_fields[
            'startdate'].custom_widget = FriendlyDatetimeDisplayWidget('le')
        form_fields[
            'enddate'].custom_widget = FriendlyDatetimeDisplayWidget('le')
        if self.request.principal.id == 'zope.anybody':
            form_fields = form_fields.omit(
                'code', 'prefix', 'year', 'mode', 'hidden',
                'strict_deadline', 'application_category',
                'application_slip_notice', 'application_fee', 'with_picture')
        return form_fields

class CustomApplicantDisplayFormPage(NigeriaApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    @property
    def form_fields(self):
        if self.target is not None and self.target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        #form_fields['perm_address'].custom_widget = BytesDisplayWidget
        form_fields['notice'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue') or self._not_paid():
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date') or self._not_paid():
            form_fields = form_fields.omit('screening_date')
        return form_fields

class CustomApplicantManageFormPage(NigeriaApplicantManageFormPage):
    """A full edit view for applicant data.
    """

    @property
    def form_fields(self):
        if self.target is not None and self.target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['student_id'].for_display = True
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(NigeriaApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    @property
    def form_fields(self):
        if self.target is not None and self.target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicantEdit)
            for field in PG_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicantEdit)
            for field in UG_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields

class CustomPDFApplicationSlip(NigeriaPDFApplicationSlip):

    @property
    def form_fields(self):
        if self.target is not None and self.target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue'):
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date'):
            form_fields = form_fields.omit('screening_date')
        return form_fields

